{ structures, physicals, shapes } ''' { integrates, merges, combines, acquires, joins, unifies, unites, links } ''' shape pattern { "names": [] "unites": [] } examples: fats: https://en.wikipedia.org/wiki/Fat { "names": [ "fats", "fat" ] "unites": [ "saturated fat" ] } { "names": [ "saturated fat" ] "unites": [] } lipids: info: calculation methods: acid hydrolysis: https://assets.thermofisher.com/TFS-Assets/CMD/Application-Notes/extraction-of-total-fat-from-food-samples-after-acid-hydrolysis-using-accelerated-solvent-extraction-with-gc-ms-analysis.pdf https://en.wikipedia.org/wiki/Lipid unites: https://en.wikipedia.org/wiki/Wax https://en.wikipedia.org/wiki/Sterol { "names": [ "lipids", "lipid" ] "unites": [ "fat", "vitamin a", "vitamin d", "vitamin e", "vitamin k" ] }